@@ -12,7 +12,6 @@ import sys
 import weakref
 import tempfile
 import os
-import imp
 import inspect
 from unittest import SkipTest
 
@@ -26,7 +25,7 @@ from .._eventloop import (
     EventLoop, EventualResult, TimeoutError, ResultRegistry, ReactorStopped)
 from .test_setup import FakeReactor
 from .. import (
-    _main, setup, retrieve_result, _store, no_setup,
+    _main, setup as setup_crochet, retrieve_result, _store, no_setup,
     run_in_reactor, wait_for)
 from ..tests import crochet_directory
 
@@ -207,7 +206,8 @@ class EventualResultTests(TestCase):
         start = time.time()
         dr = EventualResult(Deferred(), None)
         self.assertRaises(TimeoutError, dr.wait, timeout=0.03)
-        self.assertTrue(abs(time.time() - start - 0.03) < 0.005)
+        # be a little lenient for slow computers:
+        self.assertTrue(abs(time.time() - start) < 0.05)
 
     def test_timeout_twice(self):
         """
@@ -525,50 +525,6 @@ EventualResult(Deferred(), None).wait(1.0)
 """)
         self.assertRaises(RuntimeError, __import__, "shouldbeunimportable")
 
-    def test_waiting_during_different_thread_importing(self):
-        """
-        EventualResult.wait() should work if called while a module is
-        being imported in a different thread. See
-        EventualResultTests.test_noWaitingDuringImport for the explanation of
-        what should happen if an import is happening in the current thread.
-        """
-        test_complete = threading.Event()
-        lock_held = threading.Event()
-        er = EventualResult(succeed(123), None)
-
-        def other_thread():
-            imp.acquire_lock()
-            lock_held.set()
-            test_complete.wait()
-            imp.release_lock()
-
-        t = threading.Thread(target=other_thread)
-        t.start()
-        lock_held.wait()
-
-        # While the imp lock is held by the other thread, we can't
-        # allow exceptions/assertions to happen because trial will
-        # try to do an import causing a deadlock instead of a
-        # failure. We collect all assertion pairs (result, expected),
-        # wait for the import lock to be released, and then check our
-        # assertions at the end of the test.
-        assertions = []
-
-        # we want to run .wait while the other thread has the lock acquired
-        assertions.append((imp.lock_held(), True))
-        try:
-            assertions.append((er.wait(0.1), 123))
-        finally:
-            test_complete.set()
-
-        assertions.append((imp.lock_held(), True))
-
-        test_complete.set()
-
-        t.join()
-
-        [self.assertEqual(result, expected) for result, expected in assertions]
-
 
 class RunInReactorTests(TestCase):
     """
@@ -1100,7 +1056,7 @@ class PublicAPITests(TestCase):
         from twisted.python.log import startLoggingWithObserver
         from crochet import _shutdown
         self.assertIsInstance(_main, EventLoop)
-        self.assertEqual(_main.setup, setup)
+        self.assertEqual(_main.setup, setup_crochet)
         self.assertEqual(_main.no_setup, no_setup)
         self.assertEqual(_main.run_in_reactor, run_in_reactor)
         self.assertEqual(_main.wait_for, wait_for)
